AdvancedCarousel class

Inheritance

Constructors

AdvancedCarousel({Key? key, List<Widget>? items, Future<List<Widget>> itemLoader()?, double height = 200.0, bool autoPlay = true, Duration autoPlayInterval = const Duration(seconds: 3), bool infiniteScroll = true, Curve transitionCurve = Curves.easeInOut, Duration transitionDuration = const Duration(milliseconds: 500), bool showIndicator = true, Color indicatorColor = Colors.white, double indicatorSize = 8.0, Alignment indicatorAlignment = Alignment.bottomCenter, BoxShape indicatorShape = BoxShape.circle, bool pauseOnHover = false, ValueChanged<int>? onPageChanged, IndexedWidgetBuilder? itemBuilder, int itemCount = 0, TransitionEffect transitionEffect = TransitionEffect.slide, bool enableLazyLoading = true, bool accessibilityEnabled = true, dynamic onItemChanged(int)?})
const

Properties

accessibilityEnabled bool
final
autoPlay bool
final
autoPlayInterval Duration
final
enableLazyLoading bool
final
hashCode int
The hash code for this object.
no setterinherited
height double
final
indicatorAlignment Alignment
final
indicatorColor Color
final
indicatorShape BoxShape
final
indicatorSize double
final
infiniteScroll bool
final
itemBuilder IndexedWidgetBuilder?
final
itemCount int
final
itemLoader Future<List<Widget>> Function()?
final
items List<Widget>?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onItemChanged → dynamic Function(int)?
final
onPageChanged ValueChanged<int>?
final
pauseOnHover bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showIndicator bool
final
transitionCurve Curve
final
transitionDuration Duration
final
transitionEffect TransitionEffect
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _AdvancedCarouselState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited